<?php
#CMS - CMS Made Simple
#(c)2004 by Ted Kulp (wishy@users.sf.net)
#This project's homepage is: http://www.cmsmadesimple.org
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#$Id$

const CMS_VERSION_NAME             = 'Kolonia';
const CMS_SCHEMA_VERSION           = 37;
const CMS_VERSION                  = '1.12.2';
const CMS_DEFAULT_VERSIONCHECK_URL = 'http://www.cmsmadesimple.org/latest_version.php';
const CMS_SECURE_PARAM_NAME        = '_sx_';
const CMS_USER_KEY                 = '_userkey_';
const CONFIG_FILE_LOCATION         = __DIR__ . DIRECTORY_SEPARATOR . 'config.php';
const TMP_CACHE_LOCATION           = __DIR__ . DIRECTORY_SEPARATOR . 'tmp' . DIRECTORY_SEPARATOR . 'cache';
const TMP_TEMPLATES_C_LOCATION     = __DIR__ . DIRECTORY_SEPARATOR . 'tmp' . DIRECTORY_SEPARATOR . 'templates_c';

if (!is_writable(TMP_TEMPLATES_C_LOCATION) || !is_writable(TMP_CACHE_LOCATION))
{
	echo '<html><title>Error</title></head><body>';
	echo '<p>The following directories must be writable by the web server:<br />';
	echo 'tmp/cache<br />';
	echo 'tmp/templates_c<br /></p>';
	echo '<p>Please correct by executing:<br /><em>chmod 777 tmp/cache<br />chmod 777 tmp/templates_c</em><br />or the equivilent for your platform before continuing.</p>';
	echo '</body></html>';
	exit;
}

if (!file_exists(CONFIG_FILE_LOCATION) || filesize(CONFIG_FILE_LOCATION) < 100)
{
	// attempt to create the config.php if it doesn't already exist.
	@touch(CONFIG_FILE_LOCATION);
}

$_SERVER = filter_var_array($_SERVER, FILTER_SANITIZE_STRING);
array_walk_recursive($_GET, 'sanitize_input_array');

if (!isset($_SERVER['REQUEST_URI']) && isset($_SERVER['QUERY_STRING']))
{
	$_SERVER['REQUEST_URI'] = $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'];
}

require_once( __DIR__ . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'misc.functions.php' );

if ( !isset($CMS_INSTALL_PAGE) && (!file_exists(CONFIG_FILE_LOCATION) || filesize(CONFIG_FILE_LOCATION) < 100))
{
	if (FALSE == is_file(__DIR__.'/install/index.php')) 
	{
		die ('There is no config.php file or install/index.php please correct one of these errors!');
	} 
	else 
	{
		redirect('install/');
	}
}

require_once( __DIR__ . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'module.functions.php' );
require_once( __DIR__ . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'autoloader.php' );
require_once( __DIR__ . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'classes' . DIRECTORY_SEPARATOR . 'class.CmsException.php' );
require_once( __DIR__ . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'classes' . DIRECTORY_SEPARATOR . 'class.cms_config.php' );
require_once( __DIR__ . DIRECTORY_SEPARATOR . 'lib' . DIRECTORY_SEPARATOR . 'classes' . DIRECTORY_SEPARATOR . 'class.CmsApp.php' );

$config = cmsms()->GetConfig();

#Setup session with different id and start it
if( isset($CMS_ADMIN_PAGE) || isset($CMS_INSTALL_PAGE) )
{
	// admin pages can't be cached... period, at all.. never.
	session_cache_limiter('nocache');
	header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
	header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
	header("Cache-Control: no-store, no-cache, must-revalidate");
	header("Cache-Control: post-check=0, pre-check=0", false);
	header("Pragma: no-cache");
	header("Content-Type: text/html; charset=utf-8");
}
else if ($config['frontend_session'])
{
	session_cache_limiter('public');
}

if(isset($CMS_ADMIN_PAGE) || isset($CMS_INSTALL_PAGE) || $config['frontend_session'])
{
	$session_name = 'CMSSESSID' . substr( md5( __DIR__ ) , 0 , 12 );
	if( !isset($CMS_INSTALL_PAGE) )
	{
		session_name($session_name);
		ini_set('url_rewriter.tags', '');
		ini_set('session.use_trans_sid', 0);
	}
	
	if( isset($_COOKIE[$session_name]) ) {
		// validate the contents of the cookie.
		if (!preg_match('/^[a-zA-Z0-9,\-]{22,40}$/', $_COOKIE[$session_name]) ) {
			session_id( uniqid() );
			session_start();
			session_regenerate_id();
		}
	}
	
	if(!session_id())
		session_start();
}

if( isset($CMS_ADMIN_PAGE) )
{
	if( !isset($_SESSION[CMS_USER_KEY]) )
	{
		if( isset($_COOKIE[CMS_SECURE_PARAM_NAME]) )
		{
			$_SESSION[CMS_USER_KEY] = $_COOKIE[CMS_SECURE_PARAM_NAME];
		}
		else
		{
			// maybe change this algorithm.
			$key = substr(str_shuffle(sha1(__DIR__.time().session_id())),-16);
			$_SESSION[CMS_USER_KEY] = $key;
			cms_cookies::set(CMS_SECURE_PARAM_NAME,$key);
		}
	}
}

#Set the timezone
if( $config['timezone'] != '' )
{
	date_default_timezone_set(trim($config['timezone']));
}

#Attempt to override the php memory limit
if( isset($config['php_memory_limit']) && !empty($config['php_memory_limit'])  )
{
	ini_set('memory_limit',trim($config['php_memory_limit']));
}

#Add users if they exist in the session
cmsms()->set_variable('user_id','');
cmsms()->set_variable('username','');
if (isset($_SESSION['cms_admin_user_id']))
{
	cmsms()->set_variable('user_id',$_SESSION['cms_admin_user_id']);
}
if (isset($_SESSION['cms_admin_username']))
{
	cmsms()->set_variable('username',$_SESSION['cms_admin_username']);
}

require_once(__DIR__.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'adodb.functions.php');
load_adodb();

require_once(__DIR__.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'page.functions.php');
require_once(__DIR__.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'content.functions.php');
require_once(__DIR__.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'translation.functions.php');
require_once(__DIR__.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'html_entity_decode_php4.php');


#Load them into the usual variables.  This'll go away a little later on.
global $DONT_LOAD_DB;
if (!isset($DONT_LOAD_DB))
{
		cmsms()->GetDb();
	
	if( isset($CMS_ADMIN_PAGE) && !isset($CMS_LOGIN_PAGE) ) {
		$db = cmsms()->GetDb();
		$current_version = CMS_SCHEMA_VERSION;
		$query = "SELECT version from ".cms_db_prefix()."version";
		$current_version = $db->GetOne($query);
		if ($current_version < CMS_SCHEMA_VERSION) {
			redirect($config['root_url'] . "/install/upgrade.php");
		}
	}
}

$smarty = cmsms()->GetSmarty();

#Fix for IIS (and others) to make sure REQUEST_URI is filled in
if (!isset($_SERVER['REQUEST_URI']))
{
	$_SERVER['REQUEST_URI'] = $_SERVER['SCRIPT_NAME'];
	if(isset($_SERVER['QUERY_STRING']))
	{
		$_SERVER['REQUEST_URI'] .= '?'.$_SERVER['QUERY_STRING'];
	}
}

#Set a umask
$global_umask = get_site_preference('global_umask','');
if( $global_umask != '' )
{
	@umask( octdec($global_umask) );
}

$smarty->debugging = $config['debug'];
$smarty->error_reporting = error_reporting();

#Load all installed module code
if (! isset($CMS_INSTALL_PAGE))
{
	$modops = cmsms()->GetModuleOperations();
	$modops->LoadModules(isset($LOAD_ALL_MODULES), !isset($CMS_ADMIN_PAGE));
}

#Setup language stuff.... will auto-detect languages (Launch only to admin at this point)
if(isset($CMS_ADMIN_PAGE))
	CmsNlsOperations::set_language();

$CMS_LAZYLOAD_MODULES = 1; // still used ??

#Do auto task stuff.
if (! isset($CMS_INSTALL_PAGE))
{
	CmsRegularTaskHandler::handle_tasks();
}

$smarty->assign('sitename', get_site_preference('sitename', 'CMSMS Site'));

function sanitize_input_array(&$value, $key)
{
	$value = preg_replace('/\<\/?script[^\>]*\>/i', '', $value); //the i makes it caseinsensitive
	$value = preg_replace('/javascript\:/i', '', $value); //the i makes it caseinsensitive
}

# vim:ts=4 sw=4 noet
?>
